# gsdesign-python

[![PyPI version](https://img.shields.io/pypi/v/gsdesign)](https://pypi.org/project/gsdesign/)
![Python versions](https://img.shields.io/pypi/pyversions/gsdesign)
[![CI tests](https://github.com/nanxstats/gsdesign-python/actions/workflows/ci-tests.yml/badge.svg)](https://github.com/nanxstats/gsdesign-python/actions/workflows/ci-tests.yml)
[![Mypy check](https://github.com/nanxstats/gsdesign-python/actions/workflows/mypy.yml/badge.svg)](https://github.com/nanxstats/gsdesign-python/actions/workflows/mypy.yml)
[![Ruff check](https://github.com/nanxstats/gsdesign-python/actions/workflows/ruff-check.yml/badge.svg)](https://github.com/nanxstats/gsdesign-python/actions/workflows/ruff-check.yml)
![License](https://img.shields.io/pypi/l/gsdesign)

gsdesign-python is an experimental Python package for group sequential design.

## Installation

You can install gsdesign-python from PyPI:

```bash
pip install gsdesign
```

Or install the development version from GitHub:

```bash
git clone https://github.com/nanxstats/gsdesign-python.git
cd gsdesign-python
python3 -m pip install -e .
```
